package Mail::Miner::Config;

our ($db, $username, $password) = 
    ("", "", "");

1;

